.. venco.py documentation master file, created by
   sphinx-quickstart on Tue Feb  4 09:27:27 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _functions:

Functions
===================================

You can search for the different modules and functions below:

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

This part of the documentation holds the function definitions of venco.py from the main run file
´run.py´ and the library files.



.. automodule:: vencopy.core.dataparsers.dataparsers
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: vencopy.core.dataparsers.parkinference
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: vencopy.core.dataparsers.parseMiD
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: vencopy.core.dataparsers.parseKiD
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: vencopy.core.gridmodellers
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: vencopy.core.flexestimators
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: vencopy.core.diarybuilders
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: vencopy.core.profileaggregators
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: vencopy.core.postprocessors
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: vencopy.utils.utils
    :members:
    :undoc-members:
    :show-inheritance:


